npd

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 10, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

const (
	DefaultVersion = "v1.35.1"
)
const (
	KubeletKubeconfigPath = "/var/lib/kubelet/kubelet/kubeconfig"
)

Variables

This section is empty.

Functions

func Download

func Download(cfg *config.Config, machineDir string) phases.Task

Download returns a task that downloads the node-problem-detector binary and config from the upstream GitHub release tarball into the nspawn machine rootfs at machineDir.

func Start

func Start(cfg *config.Config, log *slog.Logger, machineDir, machineName string) phases.Task

Start returns a task that renders the NPD systemd unit file into the nspawn machine rootfs and ensures the service is running inside the container via systemd-run --machine.

Types

This section is empty.

Jump to